@@ -12,6 +12,11 @@ from tensorflow.keras.layers import Input, Dense
 from tensorflow.keras.optimizers import Adam
 from tensorflow.keras import Model
 from tqdm import tqdm
+import time
+import git
+import tempfile
+import shutil
+import json
 
 logging.getLogger('tensorflow').setLevel(logging.ERROR)  # suppress warnings
 os.system('clear')
@@ -27,49 +32,88 @@ def get_ASTROMER(num_layers=2,
                  maxlen=100,
                  batch_size=None,
                  pretrained_weights=False):
-
-    serie  = Input(shape=(maxlen, 1),
-                  batch_size=None,
-                  name='input')
-    times  = Input(shape=(maxlen, 1),
-                  batch_size=None,
-                  name='times')
-    mask   = Input(shape=(maxlen, 1),
-                  batch_size=None,
-                  name='mask')
-    length = Input(shape=(maxlen,),
-                  batch_size=None,
-                  dtype=tf.int32,
-                  name='length')
-
-    placeholder = {'input':serie,
-                   'mask_in':mask,
-                   'times':times,
-                   'length':length}
-
-    encoder = Encoder(num_layers,
-                d_model,
-                num_heads,
-                dff,
-                base=base,
-                rate=dropout,
-                use_leak=use_leak,
-                name='encoder')
-
-    if no_train:
-        encoder.trainable = False
-
-    x = encoder(placeholder)
-
-    x = RegLayer(name='regression')(x)
-    model = Model(inputs=placeholder,
-                 outputs=x,
-                 name="ASTROMER")
-
     if pretrained_weights:
-        model = load_weights(model, git_link="https://github.com/HarshVardhanGoyal/test_model.git", model_name="astromer_10022021")
+        #model = load_weights(git_link="https://github.com/HarshVardhanGoyal/test_model.git", model_name="astromer_10022021")
+        model_name="astromer_10022021"
+        git_link="https://github.com/HarshVardhanGoyal/test_model.git"
+        model_path = os.path.join(os.getcwd(),"weights")
+    
+        try: 
+            test_dir = tempfile.mkdtemp()
+            git.Repo.clone_from(git_link, test_dir, branch='main', depth=1)
+            time.sleep(2)
+            if os.path.isdir(model_path):
+                if overwrite:
+                    shutil.rmtree(model_path)
+                else:
+                    print("The saved weights already exists")
+        except:
+            print("Couldn't load the model")
+        finally:
+            os.mkdir(model_path)
+            shutil.move(os.path.join(test_dir, model_name), model_path)
+        # shutil.rmtree(test_dir)
+
+        conf_file = os.path.join( model_path, model_name, 'conf.json')
+        with open(conf_file, 'r') as handle:
+            conf = json.load(handle)
+
+        model = get_ASTROMER(num_layers=conf['layers'],
+                            d_model   =conf['head_dim'],
+                            num_heads =conf['heads'],
+                            dff       =conf['dff'],
+                            base      =conf['base'],
+                            dropout   =conf['dropout'],
+                            maxlen    =conf['max_obs'],
+                            use_leak  =conf['use_leak'])
+
+        # Loading the model
+        if os.path.isdir(model_path):
+            model = model.load_weights(model_path)
+
+    else:
+        serie  = Input(shape=(maxlen, 1),
+                    batch_size=None,
+                    name='input')
+        times  = Input(shape=(maxlen, 1),
+                    batch_size=None,
+                    name='times')
+        mask   = Input(shape=(maxlen, 1),
+                    batch_size=None,
+                    name='mask')
+        length = Input(shape=(maxlen,),
+                    batch_size=None,
+                    dtype=tf.int32,
+                    name='length')
+
+        placeholder = {'input':serie,
+                    'mask_in':mask,
+                    'times':times,
+                    'length':length}
+
+        encoder = Encoder(num_layers,
+                    d_model,
+                    num_heads,
+                    dff,
+                    base=base,
+                    rate=dropout,
+                    use_leak=use_leak,
+                    name='encoder')
+
+        if no_train:
+            encoder.trainable = False
+
+        x = encoder(placeholder)
+
+        x = RegLayer(name='regression')(x)
+        model = Model(inputs=placeholder,
+                    outputs=x,
+                    name="ASTROMER")
+
+    
         
-    return 
+    return model
+
 
 @tf.function
 def train_step(model, batch, opt):
